=========================
Knowledge Graph Data Tool
=========================


.. image:: https://img.shields.io/pypi/v/kgdt.svg
        :target: https://pypi.python.org/pypi/kgdt

.. image:: https://img.shields.io/travis/FudanSELab/kgdt.svg
        :target: https://travis-ci.com/FudanSELab/kgdt

.. image:: https://readthedocs.org/projects/kgdt/badge/?version=latest
        :target: https://kgdt.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




a python library for create and operate on a knowledge graph in disk/neo4j/mysql.


* Free software: MIT license
* Documentation: https://kgdt.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
